==> haskell-crypton-x509-1.7.6-66-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509
version:              1.7.6
visibility:           public
id:                   crypton-x509-1.7.6-I1TGUYohizIJVhXa44NXZm
key:                  crypton-x509-1.7.6-I1TGUYohizIJVhXa44NXZm
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X509 reader and writer
description:          X509 reader and writer. please see README
category:             Data
abi:                  62c8686c6cb8c72dc856525db43e4f53
exposed:              True
exposed-modules:      Data.X509 Data.X509.EC
hidden-modules:
    Data.X509.Internal Data.X509.CertificateChain
    Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
    Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
    Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
    Data.X509.Signed

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-x509-1.7.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-x509-1.7.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-x509-1.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509
hs-libraries:         HScrypton-x509-1.7.6-I1TGUYohizIJVhXa44NXZm
depends:
    asn1-encoding-0.9.6-GholD8Ysgt4GmfKSOPwmIn
    asn1-parse-0.9.5-FTRvFrfjqx94IkIHbcZvW2
    asn1-types-0.3.4-64aTvpzpQiK2pzFG9hgbHP base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.1-3x2lypkbPAS73y9tSsktrR
    hourglass-0.2.12-KgITAxPW4ho8TlvtJOqEZk
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    pem-0.2.4-6AJMqLEUHx21cmQxstAO8J transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509/html/crypton-x509.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-x509-1.7.6-67-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509
version:              1.7.6
visibility:           public
id:                   crypton-x509-1.7.6-58m8OpLDjXjECxSVnH16HW
key:                  crypton-x509-1.7.6-58m8OpLDjXjECxSVnH16HW
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X509 reader and writer
description:          X509 reader and writer. please see README
category:             Data
abi:                  d3045c9953b560088d62a0e8a3ae3211
exposed:              True
exposed-modules:      Data.X509 Data.X509.EC
hidden-modules:
    Data.X509.Internal Data.X509.CertificateChain
    Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
    Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
    Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
    Data.X509.Signed

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-x509-1.7.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-x509-1.7.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-x509-1.7.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509
hs-libraries:         HScrypton-x509-1.7.6-58m8OpLDjXjECxSVnH16HW
depends:
    asn1-encoding-0.9.6-9gvFptJuzHT8zKPmfp4KbJ
    asn1-parse-0.9.5-19Rc9EhYCC56oR87vneq02
    asn1-types-0.3.4-1uskTWaxwt531KJRuXpD7P base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.1-5MRSAyakhaoCBZQs9w2myH
    hourglass-0.2.12-Gk5WWDNcihV9jYp3M8lAAo
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    pem-0.2.4-AShISM1MAyF2BIVirqweyi transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509/html/crypton-x509.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
